@@ -43,11 +43,9 @@
 #include "gs-window.h"
 #include "subprocs.h"
 
-static void     gs_window_class_init     (GSWindowClass *klass);
-static void     gs_window_init           (GSWindow      *window);
 static void     gs_window_finalize       (GObject       *object);
 
-static gboolean popup_dialog_idle        (GSWindow      *window);
+static gboolean popup_dialog_idle        (gpointer user_data);
 static void     gs_window_dialog_finish  (GSWindow      *window);
 static void     gs_window_set_obscured   (GSWindow      *window,
                                           gboolean       obscured);
@@ -323,7 +321,7 @@ gs_window_move_resize_window (GSWindow *window,
     GdkWindow *gdkwindow;
 
     widget = GTK_WIDGET (window);
-    gdkwindow = gtk_widget_get_window (GTK_WIDGET (window));
+    gdkwindow = gtk_widget_get_window (widget);
 
     g_assert (gtk_widget_get_realized (widget));
 
@@ -521,7 +519,8 @@ gs_window_real_realize (GtkWidget *widget) {
 /* every so often we should raise the window in case
    another window has somehow gotten on top */
 static gboolean
-watchdog_timer (GSWindow *window) {
+watchdog_timer (gpointer user_data) {
+    GSWindow *window = user_data;
     GtkWidget *widget = GTK_WIDGET (window);
 
     gdk_window_focus (gtk_widget_get_window (widget), GDK_CURRENT_TIME);
@@ -540,9 +539,7 @@ remove_watchdog_timer (GSWindow *window) {
 static void
 add_watchdog_timer (GSWindow *window,
                     glong     seconds) {
-    window->priv->watchdog_timer_id = g_timeout_add_seconds (seconds,
-                                      (GSourceFunc)watchdog_timer,
-                                      window);
+    window->priv->watchdog_timer_id = g_timeout_add_seconds (seconds, watchdog_timer, window);
 }
 
 static void
@@ -555,11 +552,13 @@ remove_popup_dialog_idle (GSWindow *window) {
 
 static void
 add_popup_dialog_idle (GSWindow *window) {
-    window->priv->popup_dialog_idle_id = g_idle_add ((GSourceFunc)popup_dialog_idle, window);
+    window->priv->popup_dialog_idle_id = g_idle_add (popup_dialog_idle, window);
 }
 
 static gboolean
-emit_deactivated_idle (GSWindow *window) {
+emit_deactivated_idle (gpointer user_data) {
+    GSWindow *window = user_data;
+
     g_signal_emit (window, signals[DEACTIVATED], 0);
 
     return FALSE;
@@ -567,7 +566,7 @@ emit_deactivated_idle (GSWindow *window) {
 
 static void
 add_emit_deactivated_idle (GSWindow *window) {
-    g_idle_add ((GSourceFunc)emit_deactivated_idle, window);
+    g_idle_add (emit_deactivated_idle, window);
 }
 
 static void
@@ -799,7 +798,9 @@ set_info_text_and_icon (GSWindow   *window,
 }
 
 static gboolean
-info_bar_timeout (GSWindow *window) {
+info_bar_timeout (gpointer user_data) {
+    GSWindow *window = user_data;
+
     window->priv->info_bar_timer_id = 0;
     gtk_widget_hide (window->priv->info_bar);
     return FALSE;
@@ -822,9 +823,7 @@ gs_window_show_message (GSWindow   *window,
         g_source_remove (window->priv->info_bar_timer_id);
     }
 
-    window->priv->info_bar_timer_id = g_timeout_add_seconds (INFO_BAR_SECONDS,
-                                      (GSourceFunc)info_bar_timeout,
-                                      window);
+    window->priv->info_bar_timer_id = g_timeout_add_seconds (INFO_BAR_SECONDS, info_bar_timeout, window);
 }
 
 void
@@ -920,6 +919,7 @@ spawn_on_window (GSWindow *window,
                  char     *command,
                  int      *pid,
                  GIOFunc   watch_func,
+                 gboolean  redirect_stderr,
                  gpointer  user_data,
                  gint     *watch_id) {
     int          argc;
@@ -951,7 +951,7 @@ spawn_on_window (GSWindow *window,
                                        &child_pid,
                                        NULL,
                                        &standard_output,
-                                       &standard_error,
+                                       redirect_stderr ? &standard_error : NULL,
                                        &error);
 
     if (!result) {
@@ -983,16 +983,18 @@ spawn_on_window (GSWindow *window,
     g_io_channel_unref (channel);
 
     /* error channel */
-    channel = g_io_channel_unix_new (standard_error);
-    g_io_channel_set_close_on_unref (channel, TRUE);
-    g_io_channel_set_flags (channel,
-                            g_io_channel_get_flags (channel) | G_IO_FLAG_NONBLOCK,
-                            NULL);
-    g_io_add_watch (channel,
-                    G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_NVAL,
-                    error_watch,
-                    NULL);
-    g_io_channel_unref (channel);
+    if (redirect_stderr) {
+        channel = g_io_channel_unix_new (standard_error);
+        g_io_channel_set_close_on_unref (channel, TRUE);
+        g_io_channel_set_flags (channel,
+                                g_io_channel_get_flags (channel) | G_IO_FLAG_NONBLOCK,
+                                NULL);
+        g_io_add_watch (channel,
+                        G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_NVAL,
+                        error_watch,
+                        NULL);
+        g_io_channel_unref (channel);
+    }
 
     g_strfreev (argv);
     g_strfreev (envp);
@@ -1276,6 +1278,7 @@ embed_keyboard (GSWindow *window) {
                            window->priv->prefs->keyboard_command,
                            &window->priv->keyboard_pid,
                            (GIOFunc)keyboard_process_watch,
+                           TRUE,
                            window,
                            &window->priv->keyboard_watch_id);
     if (!res) {
@@ -1554,6 +1557,7 @@ popup_dialog (GSWindow *window) {
                               command->str,
                               &window->priv->lock_pid,
                               (GIOFunc)dialog_process_watch,
+                              FALSE,
                               window,
                               &window->priv->lock_watch_id);
     if (!result) {
@@ -1564,7 +1568,9 @@ popup_dialog (GSWindow *window) {
 }
 
 static gboolean
-popup_dialog_idle (GSWindow *window) {
+popup_dialog_idle (gpointer user_data) {
+    GSWindow *window = user_data;
+
     popup_dialog (window);
 
     window->priv->popup_dialog_idle_id = 0;
